@@ -187,7 +187,10 @@ class Logger:
 
         Path(folder).mkdir(parents=True, exist_ok=True)
 
-        self.messages.write_message('Logging started. Path: {}'.format(folder))
+        if not _converting:
+            self.messages.write_message('Logging started. Path: {}'.format(folder))
+        else:
+            self.messages.write_message('Converting started. Path: {}'.format(folder))
 
         self.packet_file = open(folder + '/nucleus_log.csv', 'w', newline='')
         self.condition_file = open(folder + '/condition_log.csv', 'w', newline='')
