@@ -7,8 +7,6 @@ class Messages:
 
     def write_message(self, message: str, skip_newline=False):
 
-        logger.info(message)
-
         if not skip_newline:
             print(message)
         else:
@@ -16,12 +14,8 @@ class Messages:
 
     def write_warning(self, message: str):
 
-        logger.warning(message)
-
         print('WARNING: {}'.format(message))
 
     def write_exception(self, message: str):
 
-        logger.error(message)
-
-        print('EXCEPTION: {}'.format(message))
\ No newline at end of file
+        print('EXCEPTION: {}'.format(message))
