@@ -126,11 +126,12 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_LOGGING)
     def do_start(self, _):
 
-        if self.nucleus_driver.connection.get_connection_status():
-            self.nucleus_driver.start_logging()
-            self.nucleus_driver.start_measurement()
-        else:
+        if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
+        self.nucleus_driver.start_logging()
+        self.nucleus_driver.start_measurement()
 
     start_field_calibration_parser = Cmd2ArgumentParser(description='Start field calibration')
 
@@ -138,11 +139,12 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_LOGGING)
     def do_fieldcal(self, _):
 
-        if self.nucleus_driver.connection.get_connection_status():
-            self.nucleus_driver.start_logging()
-            self.nucleus_driver.start_fieldcal()
-        else:
+        if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
+        self.nucleus_driver.start_logging()
+        self.nucleus_driver.start_fieldcal()
 
     stop_measurement_parser = Cmd2ArgumentParser(description='Stop measurement')
 
@@ -150,11 +152,12 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_LOGGING)
     def do_stop(self, _):
 
-        if self.nucleus_driver.connection.get_connection_status():
-            self.nucleus_driver.stop_logging()
-            self.nucleus_driver.stop()
-        else:
+        if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
+        self.nucleus_driver.stop_logging()
+        self.nucleus_driver.stop()
 
     set_log_path_parser = Cmd2ArgumentParser(description='Set path for log files')
     set_log_path_parser.add_argument('path', help='Set path for log files', completer=cmd2.Cmd.path_complete)
@@ -179,10 +182,11 @@ class App(cmd2.Cmd):
 
         command = command_args.command
 
-        if self.nucleus_driver.connection.get_connection_status():
-            self.nucleus_driver.send_command(command)
-        else:
+        if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
+        self.nucleus_driver.send_command(command)
 
     flash_firmware_parser = Cmd2ArgumentParser(description='Flash firmware')
     flash_firmware_parser.add_argument('path', help='Set flash file. Extension must be in [.bin, .ldr, .zip]', completer=cmd2.Cmd.path_complete)
@@ -193,6 +197,10 @@ class App(cmd2.Cmd):
 
         path = set_flash_path_args.path
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         self.nucleus_driver.flash_firmware(path=path)
 
     ###########################################
@@ -216,6 +224,10 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_ASSERT)
     def do_assert_download(self, _):
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         self.nucleus_driver.read_assert()
 
         if len(self.nucleus_driver.asserts.assert_encrypted) > 1:
@@ -229,6 +241,10 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_ASSERT)
     def do_assert_clear(self, _):
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         response = self.nucleus_driver.clear_assert()
 
         for message in response:
@@ -255,6 +271,10 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_SYSLOG)
     def do_syslog_list_entries(self, _):
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         self.nucleus_driver.list_syslog()
 
     download_syslog_parser = Cmd2ArgumentParser(description='Download syslog')
@@ -263,6 +283,10 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_SYSLOG)
     def do_syslog_download(self, _):
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         self.nucleus_driver.read_syslog()
 
         if len(self.nucleus_driver.syslog.syslog_encrypted) > 1:
@@ -276,6 +300,10 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_SYSLOG)
     def do_syslog_clear(self, _):
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         response = self.nucleus_driver.clear_syslog()
 
         for message in response:
@@ -298,6 +326,10 @@ class App(cmd2.Cmd):
         sa = download_dvl_args.sa
         length = download_dvl_args.length
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         if fid is not None:
             fid = int(fid)
 
@@ -327,6 +359,10 @@ class App(cmd2.Cmd):
         sa = download_nucleus_args.sa
         length = download_nucleus_args.length
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         if fid is not None:
             fid = int(fid)
 
@@ -355,12 +391,12 @@ class App(cmd2.Cmd):
         status = self.nucleus_driver.convert_nucleus_data(path=path)
 
         if status:
-            self.nucleus_driver.messages.write_message('Successfully converted data')
+            self.nucleus_driver.messages.write_message('Data conversion complete')
         else:
-            self.nucleus_driver.messages.write_warning('Failed to completely convert data')
+            self.nucleus_driver.messages.write_warning('Failed to convert data')
 
     list_files_parser = Cmd2ArgumentParser(description='List Nucleus or DVL files')
-    list_files_parser.add_argument('data_type', choices=['nucleus', 'dvl'], help='List Nucleus data or DVL diagnostics data')
+    list_files_parser.add_argument('data_type', choices=['nucleus', 'dvl', 'getall'], help='List Nucleus data or DVL diagnostics data')
 
     @with_argparser(list_files_parser)
     @with_category(CMD_CAT_DOWNLOAD)
@@ -368,11 +404,17 @@ class App(cmd2.Cmd):
 
         data_type = list_files_args.data_type
 
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('Nucleus not connected')
+            return
+
         src = None
         if data_type == 'nucleus':
             src = 0
         if data_type == 'dvl':
             src = 1
+        if data_type == 'getall':
+            src = 2
 
         response = self.nucleus_driver.commands.list_files(src=src)
 
